/***************************************************************************
 * LPRng - An Extended Print Spooler System
 *
 * Copyright 1988-2003, Patrick Powell, San Diego, CA
 *     papowell@lprng.com
 * See LICENSE for conditions of use.
 * $Id: sendmail.h,v 1.74 2004/09/24 20:20:01 papowell Exp $
 ***************************************************************************/



#ifndef _SENDMAIL_1_
#define _SENDMAIL_1_ 1

/* PROTOTYPES */
void Sendmail_to_user( int retval, struct job *job );

#endif
